require 'jncalculator'
require 'test/unit'

class JNCalculatorTester < Test::Unit::TestCase
  def new
    parser = JNCalculator.new(Component.LLDN)
    #parser.instance_eval {@@yydebug = true}
    parser
  end

  def test_empty
    assert_nil new().parse('')
  end

  def test_primary
    parser = new()
    assert_equal 0, parser.parse('0')
    assert_equal 0, parser.parse('')
    assert_equal 1, parser.parse('1')
    assert_equal 1, parser.parse('')
    assert_equal 10, parser.parse('10')
    assert_equal 10, parser.parse('')
    assert_equal 10000, parser.parse('10000')
    assert_equal 10000, parser.parse('')
  end

  def test_plus
    parser = new()
    assert_equal 1+0, parser.parse('1+0')
    assert_equal 1+0, parser.parse('ܡ')
    assert_equal 10+15, parser.parse('10+15')
    assert_equal 10+15, parser.parse('ܽ')
    assert_equal 10000+123, parser.parse('ɴ󽽻')
    assert_equal 10**88+1, parser.parse('̵ܰ')
  end

  def test_minus
    parser = new()
    assert_equal 1-0, parser.parse('1+0')
    assert_equal 1-0, parser.parse('ܡ')
    assert_equal 1-1, parser.parse('1-1')
    assert_equal 1-1, parser.parse('ݰ')
    assert_equal 0-1, parser.parse('0-1')
    assert_equal 0-1, parser.parse('ݰ')
    assert_equal 10**88-1, parser.parse('̵ݰ')
  end

  def test_mul
    parser = new()
    assert_equal 1*1, parser.parse('1*1')
    assert_equal 1*1, parser.parse('߰')
    assert_equal 1*0, parser.parse('1*0')
    assert_equal 1*0, parser.parse('ߡ')
    assert_equal 3*4, parser.parse('߻')
    assert_equal 4*3, parser.parse('͡߻')
    assert_equal 999*999, parser.parse('ɴ彽߶ɴ彽')
  end

  def test_div
    parser = new()
    assert_equal 2/2, parser.parse('2/2')
    assert_equal 2/2, parser.parse('')
    assert_equal 50/10, parser.parse('50/10')
    assert_equal 50/10, parser.parse('޽ཽ')
    assert_equal 10**88/5, parser.parse('̵')
    assert_in_delta 0.5, parser.parse(''), 0.2
    assert_raise(ZeroDivisionError) {
      parser.parse('5/0+2')
    }
    assert_raise(ZeroDivisionError) {
      parser.parse('ޡࡻ')
    }
    assert_equal 1+1+1, parser.parse('1+1+1')   # check parser reset
  end
end
